'''
Consts for detecting chinese chars.
'''
from typing import Sequence, Tuple

#: Chinese Chars.
#: Pulled from https://www.qqxiuzi.cn/zh/hanzi-unicode-bianma.php
#:
#: Range generation::
#:
#:  lines = '''copy paste the table here'''
#:  [l.split('\t') for l in lines.strip().split('\n')]
ITV_CHINESE: Sequence[Sequence[Tuple[int, int]]] = [[
    (0x4E00, 0x9FA5),
    (0x9FA6, 0x9FEF),
    (0x3400, 0x4DB5),
    (0x20000, 0x2A6D6),
    (0x2A700, 0x2B734),
    (0x2B740, 0x2B81D),
    (0x2B820, 0x2CEA1),
    (0x2CEB0, 0x2EBE0),
    (0x2F00, 0x2FD5),
    (0x2E80, 0x2EF3),
    (0xF900, 0xFAD9),
    (0x2F800, 0x2FA1D),
    (0xE815, 0xE86F),
    (0xE400, 0xE5E8),
    (0xE600, 0xE6CF),
    (0x3007, 0x3007),
    (0x31C0, 0x31E3),
    (0x2FF0, 0x2FFB),
    (0x3105, 0x312F),
    (0x31A0, 0x31BA),
]]

# From vkit.text.lexicon.builder:extract_radicals_from_unihan
CHINESE_RADICAL = {
    # Add manually.
    '彳',
    '丬',
    '乚',
    '丄',
    '乛',
    # From build_black_list_from_unihan:
    '㓁',
    '㔾',
    '㣺',
    # '䑕',
    # '业',
    '丨',
    '丶',
    '丿',
    '亅',
    '亠',
    '亻',
    # '儿',
    '冂',
    '冖',
    '冫',
    '凵',
    '刂',
    '勹',
    '匚',
    '匸',
    '卩',
    # '厂',
    '厶',
    '夂',
    '夊',
    '宀',
    # '宍',
    # '寸',
    # '尢',
    # '尣',
    # '尸',
    # '屮',  # COMMONLY USED.
    '巛',
    # '巾',
    '廴',
    # '廾',
    # '弓',
    '彐',
    '彑',
    '彡',
    '忄',
    '扌',
    # '攴',
    '攵',
    # '斤',
    # '无',
    # '曰',
    # '月',
    # '欠',
    # '歯',
    # '气',
    '氵',
    '灬',
    '爫',
    # '父',
    '爿',
    # '牛',
    '牜',
    # '犬',
    '犭',
    # '玄',
    '疒',
    '癶',
    # '矛',
    '礻',
    '禸',
    # '穴',
    # '竹',
    # '糸',
    '糹',
    '纟',
    # '网',
    '罒',
    # '羊',
    '耂',
    '肀',
    # '肉',
    # '肭',
    # '舌',
    # '舟',
    # '艸',
    # '艹',  # COMMONLY USED.
    '虍',
    # '虫',
    # '血',
    '衤',
    '襾',
    '覀',
    '訁',
    '讠',
    # '豕',
    # '豸',
    # '辵',
    '辶',
    # '釆',
    '釒',
    '钅',
    '阝',
    # '隶',
    # '隹',
    # '雨',
    # '韋',
    # '韦',
    # '韭',
    # '食',
    '飠',
    '饣',
    # '馬',
    # '马',
    # '髟',
    # '鬲',
    # '魚',
    # '鱼',
    # '鳥',
    # '鸟',
    # '鹿',
    # '麥',
    # '麦',
    # '黍',
    # '黹',
    # '鼠',
    # '鼻',
    # '齒',
    # '齿',
    # '鹿',
}
